function asmb = sgarray (modelFreq, obj, editParms) 

%-------------------------------------------------------------------------
% THE FIRST PART OF THIS FILE IS COMPUTER GENERATED - DO NOT EDIT IT !!!  
% PAGE DOWN TO THE USER DEFINED SECTION WHICH STARTS WITH THE SEGMENT     
% ROUTINE.                                                                
%-------------------------------------------------------------------------
% USAGE: 
%   asmb = sgarray (modelFreq, obj, editParms) 
% DESCRIPTION: 
%   A uniform dipole array.  
% INPUTS: 
%   modelFreq: The frequency at which the SNEC structure is designed
%   obj.location: The location of the assembly 
%   obj.segLength: The segment length in wavelengths 
%   obj.orientation: The orientation of the assembly 
%   obj.freqScale: The factor by which the model freq. is scaled 
%   obj.nVert: Number of elements vertically in the array 
%   obj.dVert: Distance between vertical elements (m) 
%   obj.deltaVert: Incremental phase shift per horizontal element---delta  (degrees) 
%   obj.len: Length of dipoles (m) 
%   obj.nHoriz: Number of elements horizontally in the array 
%   obj.dHoriz: Number of elements horizontally in the array 
%   obj.deltaHoriz: Incremental phase shift per horizontal element---delta  (degrees) 
%   obj.binomial: Binomial array magnitudes? 
%
% OUTPUTS: 
%   struct assembly 
%   { 
%      name       // the name of the assembly             
%      properties // array of structs                     
%      segments   // cell array of startPt, endPt, radius 
%      plates     // cell array of plate data             
%      cylinders  // cell array of cylinder data          
%      assemblies // cell array of structs like this      
%   }    

  if (nargin < 1) 
    ErrorDlg ('You must specify the model freq when calling sgarray','sgarray Usage Error'); 
    asmb = []; 
    return; 
  end 

  switch nargin 
    case 1 
      obj.location = [0.000, 0.000, 0.000]; 
      obj.segLength = 0.100; 
      obj.orientation = [0.000, 0.000, 0.000]; 
      obj.freqScale = 1.000; 
      obj.nVert = 1; 
      obj.dVert = 0.750; 
      obj.deltaVert = 0.000; 
      obj.len = 0.500; 
      obj.nHoriz = 2; 
      obj.dHoriz = 0.500; 
      obj.deltaHoriz = 0.000; 
      obj.binomial = 0; 
      editParms = 1; 
    case 2 
      editParms = 1; 
    case 3 
      % do nothing 
    otherwise 
      asmb = []; 
      ErrorDlg ('Invalid number of inputs to sgarray','sgarray Usage Error'); 
      return; 
    end 

  commonStruct = struct(... 
    'prompt',{'Location';'Segment Length';'Orientation';'Freq. Scaling'}, ... 
    'value',{obj.location; obj.segLength; obj.orientation; obj.freqScale}, ... 
    'type',{'real';'real';'real';'real'}, ... 
    'length',{3; 1; 3; 1}, ... 
    'range',{[]; [0.001 0.5]; [0 360]; [1E-5 inf]}); 

  dlgStruct = struct(... 
    'prompt', {... 
               'nVert', ... 
               'dVert (m)', ... 
               'deltaVert (degrees)', ... 
               'length (m)', ... 
               'nHoriz', ... 
               'dHoriz', ... 
               'deltaHoriz (degrees)', ... 
               'binomial?'}, ... 
    'value', {obj.nVert, obj.dVert, obj.deltaVert, obj.len, obj.nHoriz, obj.dHoriz, obj.deltaHoriz, obj.binomial}, ... 
    'noOfCols', {1, 1, 1, 1, 1, 1, 1, 1}, ... 
    'noOfRows', {1, 1, 1, 1, 1, 1, 1, 1}, ... 
    'range', {[    0.9 inf ], [      0 inf ], [ -inf inf ], [      0 inf ], [    0.9 inf ], [      0 inf ], [ -inf inf ], [ 0 1 ]}, ... 
    'type', {'integer', 'real', 'real', 'real', 'integer', 'real', 'real', 'boolean'}, ... 
    'help', {... 
             'Number of elements vertically in the array', ... 
             'Distance between vertical elements (m)', ... 
             'Incremental phase shift per vertical element---delta  (degrees)', ... 
             'Length of dipoles (m)', ... 
             'Number of elements horizontally in the array', ... 
             'Distance between horizontal elements (m)', ... 
             'Incremental phase shift per horizontal element---delta  (degrees)', ... 
             'Binomial array magnitudes?'}); 

  obj.type = 'sgarray'; 
  obj.commonStruc = commonStruct; 
  obj.dlgStruc = dlgStruct; 

  if (editParms) 
    [obj,okay] = snasmbdlg (obj); 
  else 
    okay = 1; 
  end 
  if (okay) 
    location = obj.commonStruc(1).value; 
    segLength = obj.commonStruc(2).value; 
    orientation = obj.commonStruc(3).value; 
    freqScale = obj.commonStruc(4).value; 
    nVert = obj.dlgStruc(1).value; 
    dVert = obj.dlgStruc(2).value; 
    deltaVert = obj.dlgStruc(3).value; 
    len = obj.dlgStruc(4).value; 
    nHoriz = obj.dlgStruc(5).value; 
    dHoriz = obj.dlgStruc(6).value; 
    deltaHoriz = obj.dlgStruc(7).value; 
    binomial = obj.dlgStruc(8).value; 

    asmb = Segment (modelFreq, location, segLength, orientation, freqScale, nVert, dVert, deltaVert, len, nHoriz, dHoriz, deltaHoriz, binomial); 

    asmb.name = 'sgarray'; 
    asmb.properties = struct ('name',{ 'location', 'segLength', 'orientation', 'freqScale', 'nVert', 'dVert', 'deltaVert', 'len', 'nHoriz', 'dHoriz', 'deltaHoriz', 'binomial'}, ... 
      'value',{ location, segLength, orientation, freqScale, nVert, dVert, deltaVert, len, nHoriz, dHoriz, deltaHoriz, binomial}); 
  else 
    asmb = []; 
  end

%------------------------------------------------------------------------- 
% WRITE YOUR SEGMENT ROUTINE AFTER THE LINE: freqMHz = modelFreq.*freqScale;
%------------------------------------------------------------------------- 
function asmb = Segment (modelFreq, ... 
                         location, ... 
                         segLength, ... 
                         orientation, ... 
                         freqScale, ... 
                         nVert, ... 
                         dVert, ... 
                         deltaVert, ... 
                         len, ... 
                         nHoriz, ... 
                         dHoriz, ... 
                         deltaHoriz, ... 
                         binomial)
  freqMHz = modelFreq.*freqScale; 

  % Construct n sndipoles s.t. the ``isotropic'' feel is maintained, d
  % apart, with a phase INCREMENT of delta degrees. Note that orientation
  % etc must still work.
  dip.location = location;
  dip.orientation = orientation;
  dip.noOfSegs = 0;
  dip.freqScale = freqScale;
  dip.segLength = segLength;
  dip.radius = 0.001;

  % Set up the ``taper'' vector. In the simplest case, this means a
  % binomial arrangement: pascal and all that. (Obviously can be
  % generalised!) 
  if binomial
    % 1D too :-)
    if nHoriz > nVert
      larger = nHoriz;
    else 
      larger = nVert;
    end
    taper = abs(pascal(larger,1));
    taper = taper (larger,:);
  end
  % NOTE: Array theory implements ``left'' as the phase reference. In the
  % vertical sense this means the ``top'' element. Hence:
  Total = 0;
  for k = 1:nVert
    Vincrement = (nVert-(k-1))*deltaVert;
    Vincrradians = (Vincrement./180).*pi;
    for l = 1:nHoriz
      Total = Total+1;
      dip.end1 = [(l-1)*dHoriz,0,-len/2+(k-1)*dVert];
      dip.end2 = [(l-1)*dHoriz,0,len/2+(k-1)*dVert];
      Hincrement = (l-1)*deltaHoriz;
      Hincrradians = (Hincrement./180).*pi;
      incrradians = Vincrradians + Hincrradians;
      dip.voltage = cos(incrradians)+j*sin(incrradians);
      %
      % Initial Draft. Apply Taper only horizontally!! Not sure whether 2D
      % binomial really makes sense---would it be applied square, or in a
      % radius from the centre of the array??????
      % Binomial arrays need CURRENT SOURCES!
      if binomial
        dip.voltage = dip.voltage .* taper(l);
        %
        asmb.assemblies{Total}= sndipole (modelFreq, dip, 0); 
	% Need to find feed segment...
	noOfSegs=length(asmb.assemblies{Total}.segments);
	midSeg=round(noOfSegs/2);
        asmb.assemblies{Total}.segments{midSeg}.excitation{1}.type = ...
	   'CurrentSource';
        asmb.assemblies{Total}.segments{midSeg}.excitation{1}.current = ...
	   asmb.assemblies{Total}.segments{midSeg}.excitation{1}.voltage;
      else
        asmb.assemblies{Total}= sndipole (modelFreq, dip, 0); 
      end	
    end
  end
  asmb.name = 'sgarray';
  asmb.plates = {};
  asmb.cylinders = {};
  asmb.segments = {};




  
