function asmb = sgtl (modelFreq, obj, editParms) 

%-------------------------------------------------------------------------
% THE FIRST PART OF THIS FILE IS COMPUTER GENERATED - DO NOT EDIT IT !!!  
% PAGE DOWN TO THE USER DEFINED SECTION WHICH STARTS WITH THE SEGMENT     
% ROUTINE.                                                                
%-------------------------------------------------------------------------
% USAGE: 
%   asmb = sgtl (modelFreq, obj, editParms) 
% DESCRIPTION: 
%   Transmission line using a TL card  
% INPUTS: 
%   modelFreq: The frequency at which the SNEC structure is designed
%   obj.location: The location of the assembly 
%   obj.segLength: The segment length in wavelengths 
%   obj.orientation: The orientation of the assembly 
%   obj.freqScale: The factor by which the model freq. is scaled 
%   obj.x: length of transmission line (m) 
%   obj.Zl: Load Impedance (Ohms) 
%   obj.Zo: Characteristic Impedance (Ohms) 
%   obj.Src: Source Voltage (V) 
%
% OUTPUTS: 
%   struct assembly 
%   { 
%      name       // the name of the assembly             
%      properties // array of structs                     
%      segments   // cell array of startPt, endPt, radius 
%      plates     // cell array of plate data             
%      cylinders  // cell array of cylinder data          
%      assemblies // cell array of structs like this      
%   }    

  if (nargin < 1) 
    ErrorDlg ('You must specify the model freq when calling sgtl','sgtl Usage Error'); 
    asmb = []; 
    return; 
  end 

  switch nargin 
    case 1 
      obj.location = [0.000, 0.000, 0.000]; 
      obj.segLength = 0.100; 
      obj.orientation = [0.000, 0.000, 0.000]; 
      obj.freqScale = 1.000; 
      obj.x = 0.500; 
      obj.Zl = 600.000 + 0.000i; 
      obj.Zo = 300.000 + 0.000i; 
      obj.Src = 1.000 + 0.000i; 
      editParms = 1; 
    case 2 
      editParms = 1; 
    case 3 
      % do nothing 
    otherwise 
      asmb = []; 
      ErrorDlg ('Invalid number of inputs to sgtl','sgtl Usage Error'); 
      return; 
    end 

  commonStruct = struct(... 
    'prompt',{'Location';'Segment Length';'Orientation';'Freq. Scaling'}, ... 
    'value',{obj.location; obj.segLength; obj.orientation; obj.freqScale}, ... 
    'type',{'real';'real';'real';'real'}, ... 
    'length',{3; 1; 3; 1}, ... 
    'range',{[]; [0.001 0.5]; [0 360]; [1E-5 inf]}); 

  dlgStruct = struct(... 
    'prompt', {... 
               'length(m)', ... 
               'Load (Ohms)', ... 
               'Zo (Ohms)', ... 
               'source (V)'}, ... 
    'value', {obj.x, obj.Zl, obj.Zo, obj.Src}, ... 
    'noOfCols', {1, 1, 1, 1}, ... 
    'noOfRows', {1, 1, 1, 1}, ... 
    'range', {[ -inf inf ], [ -inf inf ], [ -inf inf ], [ -inf inf ]}, ... 
    'type', {'real', 'complex', 'complex', 'complex'}, ... 
    'help', {... 
             'length of transmission line (m)', ... 
             'Load Impedance (Ohms)', ... 
             'Characteristic Impedance (Ohms)', ... 
             'Source Voltage (V)'}); 

  obj.type = 'sgtl'; 
  obj.commonStruc = commonStruct; 
  obj.dlgStruc = dlgStruct; 

  if (editParms) 
    [obj,okay] = snasmbdlg (obj); 
  else 
    okay = 1; 
  end 
  if (okay) 
    location = obj.commonStruc(1).value; 
    segLength = obj.commonStruc(2).value; 
    orientation = obj.commonStruc(3).value; 
    freqScale = obj.commonStruc(4).value; 
    x = obj.dlgStruc(1).value; 
    Zl = obj.dlgStruc(2).value; 
    Zo = obj.dlgStruc(3).value; 
    Src = obj.dlgStruc(4).value; 

    asmb = Segment (modelFreq, location, segLength, orientation, freqScale, x, Zl, Zo, Src); 

    asmb.name = 'sgtl'; 
    asmb.properties = struct ('name',{ 'location', 'segLength', 'orientation', 'freqScale', 'x', 'Zl', 'Zo', 'Src'}, ... 
      'value',{ location, segLength, orientation, freqScale, x, Zl, Zo, Src}); 
  else 
    asmb = []; 
  end

%------------------------------------------------------------------------- 
% WRITE YOUR SEGMENT ROUTINE AFTER THE LINE: freqMHz = modelFreq.*freqScale;
%------------------------------------------------------------------------- 
function asmb = Segment (modelFreq, ... 
                         location, ... 
                         segLength, ... 
                         orientation, ... 
                         freqScale, ... 
                         x, ... 
                         Zl, ... 
                         Zo, ... 
                         Src)
  freqMHz = modelFreq.*freqScale; 
  % Alan Robert Clark clark@YingTongDiddleiPo.ee.wits.ac.za 
  % Created: 09 December 2003

  % Modified 30 March 2004 to reflect the final conclusions regarding
  % getting exact numerical correspondence with theory. The segments must
  % be tiny (0.01) and their conductivity must be 1/377 (ie have the same
  % impedance as free space) otherwise you do get small shifts in
  % frequency, especially in cascaded systems due to coupling. Now redo the
  % entire chapter, sheesh.

  % normalize..
  lambda = 299.8/freqMHz;
  nSegs = ceil(x./(lambda.*segLength));
  
  % Define source and load
  source.type = 'AFVS';
  source.voltage = Src;
  
  % Put in the two segments to hold the load and source respectively.
  seg.end1 = [0,0,0];
  seg.end2 = [0,0,0.01];
  seg.radius = 0.0001;
  seg.conductivity = 1/377;
  seg.coupling = 0;
  seg.loads = {}; 
  seg.excitation = {};
  asmb.segments{1}=seg;

  seg.end1 = [x,0,0];
  seg.end2 = [x,0,0.01];
  seg.radius = 0.0001;
  seg.conductivity = 1/377;
  seg.coupling = 0;
  seg.loads = {}; 
  seg.excitation{1} = source;
  asmb.segments{2}=seg;

  % Link them.
  tline.type = 'TL';
  tline.port1Seg = 1;
  tline.port2Seg = 2;
  tline.zo = Zo;
  tline.len = x;
  tline.crossed = 0;
  tline.admit1 = 1/Zl;
  tline.admit2 = 0;
  asmb.translines{1} = tline;

  % Cleanup
  asmb.assemblies = {};
  asmb.plates = {};
  asmb.cylinders = {};
