function asmb = sgtxln (modelFreq, obj, editParms) 

%-------------------------------------------------------------------------
% THE FIRST PART OF THIS FILE IS COMPUTER GENERATED - DO NOT EDIT IT !!!  
% PAGE DOWN TO THE USER DEFINED SECTION WHICH STARTS WITH THE SEGMENT     
% ROUTINE.                                                                
%-------------------------------------------------------------------------
% USAGE: 
%   asmb = sgtxln (modelFreq, obj, editParms) 
% DESCRIPTION: 
%   Study Guide : Transmission Line : A basic , terminated transmission line.  
% INPUTS: 
%   modelFreq: The frequency at which the SNEC structure is designed
%   obj.location: The location of the assembly 
%   obj.segLength: The segment length in wavelengths 
%   obj.orientation: The orientation of the assembly 
%   obj.freqScale: The factor by which the model freq. is scaled 
%   obj.x: length of transmission line (m) 
%   obj.D: Centre-to-centre spacing (m) 
%   obj.a: Radius of the wires (m) 
%   obj.Zl: Load impedance (Ohms) 
%   obj.Src: Source excitation (volts) 
%   obj.SrcMatch: Source matched to transmission line?
%   obj.Cond: Wire Conductivity (mhos/m) 
%
% OUTPUTS: 
%   struct assembly 
%   { 
%      name       // the name of the assembly             
%      properties // array of structs                     
%      segments   // cell array of startPt, endPt, radius 
%      plates     // cell array of plate data             
%      cylinders  // cell array of cylinder data          
%      assemblies // cell array of structs like this      
%   }    

  if (nargin < 1) 
    ErrorDlg ('You must specify the model freq when calling sgtxln','sgtxln Usage Error'); 
    asmb = []; 
    return; 
  end 

  switch nargin 
    case 1 
      obj.location = [0.000, 0.000, 0.000]; 
      obj.segLength = 0.100; 
      obj.orientation = [0.000, 0.000, 0.000]; 
      obj.freqScale = 1.000; 
      obj.x = 0.500; 
      obj.D = 0.01405; 
      obj.a = 0.0005; 
      obj.Zl = 400.000 + 0.000i; 
      obj.Src = 1.000 + 0.000i; 
      obj.SrcMatch = 0; 
      obj.Cond = Inf; 
      editParms = 1; 
    case 2 
      editParms = 1; 
    case 3 
      % do nothing 
    otherwise 
      asmb = []; 
      ErrorDlg ('Invalid number of inputs to sgtxln','sgtxln Usage Error'); 
      return; 
    end 

  commonStruct = struct(... 
    'prompt',{'Location';'Segment Length';'Orientation';'Freq. Scaling'}, ... 
    'value',{obj.location; obj.segLength; obj.orientation; obj.freqScale}, ... 
    'type',{'real';'real';'real';'real'}, ... 
    'length',{3; 1; 3; 1}, ... 
    'range',{[]; [0.001 0.5]; [0 360]; [1E-5 inf]}); 

  dlgStruct = struct(... 
    'prompt', {... 
               'length (m)', ... 
               'spacing (m)', ... 
               'radius (m)', ... 
               'load (Ohms)', ... 
               'source (volts)', ... 
               'source matched?', ... 
               'conductivity [mhos/m]'}, ... 
    'value', {obj.x, obj.D, obj.a, obj.Zl, obj.Src, obj.SrcMatch, obj.Cond}, ... 
    'noOfCols', {1, 1, 1, 1, 1, 1, 1}, ... 
    'noOfRows', {1, 1, 1, 1, 1, 1, 1}, ... 
    'range', {[      0 inf ], [      0 inf ], [      0 inf ], [ -inf inf ], [ -inf inf ], [ 0 1 ], [ -inf inf ]}, ... 
    'type', {'real', 'real', 'real', 'complex', 'complex', 'boolean', 'real'}, ... 
    'help', {... 
             'length of transmission line (m)', ... 
             'Centre-to-centre spacing (m)', ... 
             'Radius of the wires (m)', ... 
             'Load impedance (Ohms)', ... 
             'Source excitation (volts)', ... 
             'Source matched to transmission line?', ... 
             'Wire Conductivity [mhos/m]'}); 

  obj.type = 'sgtxln'; 
  obj.commonStruc = commonStruct; 
  obj.dlgStruc = dlgStruct; 

  if (editParms) 
    [obj,okay] = snasmbdlg (obj); 
  else 
    okay = 1; 
  end 
  if (okay) 
    location = obj.commonStruc(1).value; 
    segLength = obj.commonStruc(2).value; 
    orientation = obj.commonStruc(3).value; 
    freqScale = obj.commonStruc(4).value; 
    x = obj.dlgStruc(1).value; 
    D = obj.dlgStruc(2).value; 
    a = obj.dlgStruc(3).value; 
    Zl = obj.dlgStruc(4).value; 
    Src = obj.dlgStruc(5).value; 
    SrcMatch = obj.dlgStruc(6).value; 
    Cond = obj.dlgStruc(7).value; 

    asmb = Segment (modelFreq, location, segLength, orientation, freqScale, x, D, a, Zl, Src, SrcMatch, Cond); 

    asmb.name = 'sgtxln'; 
    asmb.properties = struct ('name',{ 'location', 'segLength', 'orientation', 'freqScale', 'x', 'D', 'a', 'Zl', 'Src', 'SrcMatch', 'Cond'}, ... 
      'value',{ location, segLength, orientation, freqScale, x, D, a, Zl, Src, SrcMatch, Cond}); 
  else 
    asmb = []; 
  end

%------------------------------------------------------------------------- 
% WRITE YOUR SEGMENT ROUTINE AFTER THE LINE: freqMHz = modelFreq.*freqScale;
%------------------------------------------------------------------------- 
function asmb = Segment (modelFreq, ... 
                         location, ... 
                         segLength, ... 
                         orientation, ... 
                         freqScale, ... 
                         x, ... 
                         D, ... 
                         a, ... 
                         Zl, ... 
                         Src, ... 
			 SrcMatch,...
                         Cond)
  freqMHz = modelFreq.*freqScale; 
  % Alan Robert Clark clark@YingTongDiddleiPo.ee.wits.ac.za 
  % Created: 22 October 2003

  % normalize..
  lambda = 299.8/freqMHz;
  nSegs = ceil(x./(lambda.*segLength));
  
  % Put in the two snwires, then the two segments to hold the load and
  % source respectively. The use of snwires automates the orientation and
  % location aspects, but unfortunately sets the conductivity hardwired to
  % Inf. Hence the tweak after the snwire call.
  wire.coord1 = [0,0,0];
  wire.coord2 = [x,0,0];
  wire.radius = a;
  wire.noOfSegs = nSegs;
  wire.location = location;
  wire.orientation = orientation; 
  wire.freqScale = freqScale; 
  wire.segLength = freqScale;
  asmb.assemblies{1} = snwire (modelFreq, wire, 0);
  
  wire.coord1 = [0,D,0];
  wire.coord2 = [x,D,0];
  asmb.assemblies{2} = snwire (modelFreq, wire, 0);
 
  % Conductivity must be done on a bloody per segment basis!, shit.
  for i = 1:nSegs
    asmb.assemblies{1}.segments{i}.conductivity = Cond;
    asmb.assemblies{2}.segments{i}.conductivity = Cond;
  end
  
  % Single segment only for the load.
  wire.coord1 = [x,0,0];
  wire.coord2 = [x,D,0];
  wire.noOfSegs = 1;
  asmb.assemblies{3} = snwire (modelFreq, wire, 0);
  load.type = 'Impedance';
  load.impedance = Zl;
  asmb.assemblies{3}.segments{1}.loads{1} = load;
  
  % Single segment (last segment for easy location purposes) must get a
  % source **AND** a load if we need the source matched to the
  % line!!!!! 
  wire.coord1 = [0,0,0];
  wire.coord2 = [0,D,0];
  asmb.assemblies{4} = snwire (modelFreq, wire, 0);
  source.type = 'AFVS';
  source.voltage = Src;
  asmb.assemblies{4}.segments{1}.excitation{1} = source;
  if SrcMatch
    load.impedance = 119.945.*acosh(D./(2.*a));
    asmb.assemblies{4}.segments{1}.loads{1} = load;
  end

  % Cleanup
  asmb.segments = {};
  asmb.plates = {};
  asmb.cylinders = {};
  
